﻿using UnityEngine;
using System.Collections;

public class Functions : MonoBehaviour {

	static System.Random rnd = new System.Random();

	//Primitive Variable Types Manipulation

	static public void invertBool(ref bool var){
		if (var == true){
			var = false;
		} else {
			var = true;
		}
	}

	//---------------------------------------------------------------------------------------
	
	//Common

	static public int getRandomInt(int minInclusive, int maxInclusive){
		return rnd.Next(minInclusive, maxInclusive + 1);
	}

	//---------------------------------------------------------------------------------------

	//Space Transformations

	static public void moveGameObjectArrayLeft(GameObject[] array, float distance){
		foreach(GameObject gameObject in array){
			gameObject.transform.position = new Vector3(gameObject.transform.position.x - distance,
			                                            gameObject.transform.position.y,
			                                            gameObject.transform.position.z);
		}
	}

	static public void moveGameObjectArrayRight(GameObject[] array, float distance){
		foreach(GameObject gameObject in array){
			gameObject.transform.position = new Vector3(gameObject.transform.position.x + distance,
			                                            gameObject.transform.position.y,
			                                            gameObject.transform.position.z);
		}
	}

	//---------------------------------------------------------------------------------------

	//Color & Alpha

	/************************************************************************
	 * 																		*
	 * For the alpha functions to work, the material should be in Fade Mode.*
	 * 																		*
	 ************************************************************************/

    static public void setSpriteAlpha(GameObject gameObject, float alpha) {
        SpriteRenderer renderer = gameObject.GetComponent<SpriteRenderer>();

        renderer.color = new Color(1.0f, 1.0f, 1.0f, alpha);
    }

	static public void setAlpha(GameObject gameObject, float alpha){
		MeshRenderer[] renderers = gameObject.GetComponentsInChildren<MeshRenderer>();
		
		for (int i = 0; i < renderers.Length; i++) {
			Color newColor = new Color( renderers[i].material.color.r, 
			                           renderers[i].material.color.g, 
			                           renderers[i].material.color.b,
			                           alpha);
			
			renderers[i].material.SetColor("_Color", newColor);
		}
	}

	static public void setAlphaToGameObjectArray(GameObject[] array, float alpha){
		foreach (GameObject gameObject in array){
			setAlpha(gameObject, alpha);
		}
	}

	static public void addAlpha(GameObject gameObject, float alpha){
		MeshRenderer[] renderers = gameObject.GetComponentsInChildren<MeshRenderer>();
		
		for (int i = 0; i < renderers.Length; i++) {
			Color newColor = new Color( renderers[i].material.color.r, 
			                           renderers[i].material.color.g, 
			                           renderers[i].material.color.b,
			                           renderers[i].material.color.a + alpha);
			
			renderers[i].material.SetColor("_Color", newColor);
		}
	}

	static public void substractAlpha(GameObject gameObject, float alpha){
		MeshRenderer[] renderers = gameObject.GetComponentsInChildren<MeshRenderer>();
		
		for (int i = 0; i < renderers.Length; i++) {
			Color newColor = new Color( renderers[i].material.color.r, 
			                           renderers[i].material.color.g, 
			                           renderers[i].material.color.b,
			                           renderers[i].material.color.a - alpha);
			
			renderers[i].material.SetColor("_Color", newColor);
		}
	}

	static public void addAlphaToGameObjectArray(GameObject[] array, float alpha){
		foreach (GameObject gameObject in array){
			addAlpha(gameObject, alpha);
		}
	}
	
	static public void substractAlphaToGameObjectArray(GameObject[] array, float alpha){
		foreach (GameObject gameObject in array){
			substractAlpha(gameObject, alpha);
		}
	}

	static public float getAlpha(GameObject gameObject){
		MeshRenderer renderer = gameObject.GetComponentsInChildren<MeshRenderer>()[0];

		return renderer.material.color.a;
	}

	static public void highlight(GameObject gameObject, string color){

		

		MeshRenderer renderer = gameObject.GetComponentsInChildren<MeshRenderer>()[0];
		Color outColor;

		switch (color){
			case "Normal":
				outColor = Color.white;
				break;
			case "Gray":
				outColor = Color.gray;
				break;
			case "Grey":
				outColor = Color.grey;
				break;
			case "Red":
				outColor = Color.red;
				break;
			case "Green":
				outColor = Color.green;
				break;
			case "Yellow":
				outColor = Color.yellow;
				break;
			case "Blue":
				outColor = Color.blue;
				break;
			case "Black":
				outColor = Color.black;
				break;
			default:
				ColorUtility.TryParseHtmlString(color, out outColor);
				break;
		}

		renderer.material.color = outColor;

		/*

		MeshRenderer renderer = gameObject.GetComponentsInChildren<MeshRenderer>()[0];
		Color outColor;
		
		switch (color){
		case "Normal":
			outColor = Color.white;
			break;
		case "Gray":
			outColor = Color.gray;
			break;
		case "Grey":
			outColor = Color.grey;
			break;
		case "Red":
			outColor = Color.red;
			break;
		case "Green":
			outColor = Color.green;
			break;
		case "Yellow":
			outColor = Color.yellow;
			break;
		case "Blue":
			outColor = Color.blue;
			break;
		case "Black":
			outColor = Color.black;
			break;
		default:
			Color.TryParseHexString(color, out outColor);
			break;
		}
		renderer.material.color = outColor;
          
         */
	}

    static public void highlightSprite(GameObject gameObject, string color)
    {
        /*

		SpriteRenderer renderer = gameObject.GetComponentsInChildren<SpriteRenderer>()[0];
		Color outColor;
		
		switch (color){
		case "Normal":
			outColor = Color.white;
			break;
		case "Gray":
			outColor = Color.gray;
			break;
		case "Grey":
			outColor = Color.grey;
			break;
		case "Red":
			outColor = Color.red;
			break;
		case "Green":
			outColor = Color.green;
			break;
		case "Yellow":
			outColor = Color.yellow;
			break;
		case "Blue":
			outColor = Color.blue;
			break;
		case "Black":
			outColor = Color.black;
			break;
		default:
			Color.TryParseHexString(color, out outColor);
			break;
		}
		renderer.material.color = outColor;

		*/

        SpriteRenderer renderer = gameObject.GetComponentsInChildren<SpriteRenderer>()[0];
        Color outColor;

        switch (color)
        {
            case "Normal":
                outColor = Color.white;
                break;
            case "Gray":
                outColor = Color.gray;
                break;
            case "Grey":
                outColor = Color.grey;
                break;
            case "Red":
                outColor = Color.red;
                break;
            case "Green":
                outColor = Color.green;
                break;
            case "Yellow":
                outColor = Color.yellow;
                break;
            case "Blue":
                outColor = Color.blue;
                break;
            case "Black":
                outColor = Color.black;
                break;
            default:
                ColorUtility.TryParseHtmlString(color, out outColor);
                break;
        }

        renderer.material.color = outColor;

		
    }
}
