﻿using UnityEngine;
using System.Collections;

public class GameScript : MonoBehaviour {

	public static int nRows = 7;
	public static int nCols = 16; //7 + 2 + 7

	static int tileWidth = 64;
	static int tileHeight = 64;

	static int screenWidth;
	static int screenHeight;
	static Vector2 topLeft;
	static Vector2 botRight;

	static public int[,] map;
	static public GameObject[,] tiles;
    static public TilesScript[,] tilesScripts;

	static public string[] tilePaths;

    static public GameObject charA1; static public ElementScript scriptA1;
    static public GameObject charB1; static public ElementScript scriptB1;
    static public GameObject charC1; static public ElementScript scriptC1;

    static public GameObject charA2; static public ElementScript scriptA2;
    static public GameObject charB2; static public ElementScript scriptB2;
    static public GameObject charC2; static public ElementScript scriptC2;

    static public ElementScript scriptSelected;

    static public int playerTurn = 1;
    static public int elementSelected = 1;
    static public TilesScript selectedTile;

    static public bool isMoving = false;
    static public bool gameStarted = false;

    static public int charOffsetY = -15;

    static public bool extraTurn = false;
    static public ElementScript extraElement;

    static public GameObject pUpInspection1;
    static public GameObject pUpInspection2;

	static public GameObject pUpMist1;
	static public GameObject pUpMist2;

	static public int[] arrayMistX;
	static public int[] arrayMistY;
	static public int arrayMistCount = 0;

	static public GameObject pUpObserver1;
	static public GameObject pUpObserver2;

	static public int[] arrayObserverX;
	static public int[] arrayObserverY;
	static public int arrayObserverCount = 0;
	static public float observerTimer = 2.0f;

	static public GameObject pUpTornado1;
	static public GameObject pUpTornado2;

	static public GameObject pUpStone1;
	static public GameObject pUpStone2;

	static public Messages msgPlayer1;
	static public Messages msgPlayer2;
	static public Messages msgFireVsEarth;
	static public Messages msgWaterVsFire;
	static public Messages msgEarthVsWater;
	static public Messages msgTornado;
	static public Messages msgObserver;
	static public Messages msgInspector;
	static public Messages msgStone;
	static public Messages msgMist;
	static public Messages msgMoveAgain;

    static public GameObject[,] tilesTrans;

    static public int nPlayers = 2;

	void Start () {
		map = new int[nCols, nRows];
		tiles = new GameObject[nCols, nRows];
        tilesTrans = new GameObject[nCols, nRows];
        tilesScripts = new TilesScript[nCols, nRows];
		arrayMistX = new int[50];
		arrayMistY = new int[50];
		arrayObserverX = new int[50];
		arrayObserverY = new int[50];

		msgPlayer1 = GameObject.Find("player1").GetComponent<Messages>();
		msgPlayer2 = GameObject.Find("player2").GetComponent<Messages>();
		msgFireVsEarth = GameObject.Find("fireVsEarth").GetComponent<Messages>();
		msgWaterVsFire = GameObject.Find("waterVsFire").GetComponent<Messages>();
		msgEarthVsWater = GameObject.Find("earthVsWater").GetComponent<Messages>();
		msgTornado = GameObject.Find("tornadoIncoming").GetComponent<Messages>();
		msgObserver = GameObject.Find("seeOccult").GetComponent<Messages>();
		msgInspector = GameObject.Find("tilliumRevellium").GetComponent<Messages>();
		msgStone = GameObject.Find("blockPath").GetComponent<Messages>();
		msgMist = GameObject.Find("bewareMist").GetComponent<Messages>();
		msgMoveAgain = GameObject.Find("moveAgain").GetComponent<Messages>();

		setCameraProperties();

		fillPaths();

		createMap();
		setRandomTiles();
        //setAllWaterTiles(); //This is for testing
		setMiddleSection();
        setPowerUps();
		hideTiles();
        createCharacters();

        scriptSelected = scriptA1;
        scriptA1.setSelected(true);
		msgPlayer1.display();
	}

    void Update() {

        if (Input.GetKeyDown(KeyCode.Escape)) {
            Application.Quit();
        }

        if (!gameStarted){
            scriptA1.setSelected(true);
            gameStarted = true;
        }

		if (arrayObserverCount > 0){
			observerTimer -= 0.01f;

			if (observerTimer <= 0){
				observerTimer = 2.0f;

				for (int i = 0; i < GameScript.arrayObserverCount; i++){
					GameScript.tilesScripts[GameScript.arrayObserverX[i], GameScript.arrayObserverY[i]].hide();
				}
			
				GameScript.arrayObserverX = new int[50];
				GameScript.arrayObserverY = new int[50];
				GameScript.arrayObserverCount = 0;
			}
		} else if (!isMoving && !extraTurn) {
            checkInput();
        } else if (extraTurn) {
            checkInputExtraTurn();
        }
    }

    void setPowerUps() {
		//-----------------------------------------------
        int posX = Functions.getRandomInt(1, GameScript.nCols / 2 - 2);
        int posY = Functions.getRandomInt(0, GameScript.nRows - 1);

        pUpInspection1 = (GameObject)Instantiate(Resources.Load(Paths.pUpInspection), new Vector3(tilesScripts[posX, posY].transform.position.x, tilesScripts[posX, posY].transform.position.y - charOffsetY, 0), new Quaternion(0, 0, 0, 0));

		changeTile(posX, posY, 1);
		tilesScripts[posX, posY].element = "Inspection";

		Functions.setSpriteAlpha(pUpInspection1, 0.0f);
		//-----------------------------------------------
		posX = Functions.getRandomInt(GameScript.nCols / 2 + 1, GameScript.nCols - 2);
		posY = Functions.getRandomInt(0, GameScript.nRows - 1);
		
		pUpInspection2 = (GameObject)Instantiate(Resources.Load(Paths.pUpInspection), new Vector3(tilesScripts[posX, posY].transform.position.x, tilesScripts[posX, posY].transform.position.y - charOffsetY, 0), new Quaternion(0, 0, 0, 0));
		
		changeTile(posX, posY, 1);
		tilesScripts[posX, posY].element = "Inspection";

		Functions.setSpriteAlpha(pUpInspection2, 0.0f);
		//-----------------------------------------------
		posX = Functions.getRandomInt(1, GameScript.nCols / 2 - 2);
		posY = Functions.getRandomInt(0, GameScript.nRows - 1);

		pUpMist1 = (GameObject)Instantiate(Resources.Load(Paths.pUpMist), new Vector3(tilesScripts[posX, posY].transform.position.x, tilesScripts[posX, posY].transform.position.y - charOffsetY, 0), new Quaternion(0, 0, 0, 0));

		changeTile(posX, posY, 1);
		tilesScripts[posX, posY].element = "Mist";

		Functions.setSpriteAlpha(pUpMist1, 0.0f);
		//-----------------------------------------------
		posX = Functions.getRandomInt(GameScript.nCols / 2 + 1, GameScript.nCols - 2);
		posY = Functions.getRandomInt(0, GameScript.nRows - 1);

		pUpMist2 = (GameObject)Instantiate(Resources.Load(Paths.pUpMist), new Vector3(tilesScripts[posX, posY].transform.position.x, tilesScripts[posX, posY].transform.position.y - charOffsetY, 0), new Quaternion(0, 0, 0, 0));
		
		changeTile(posX, posY, 1);
		tilesScripts[posX, posY].element = "Mist";
		
		Functions.setSpriteAlpha(pUpMist2, 0.0f);
		//-----------------------------------------------
		posX = Functions.getRandomInt(1, GameScript.nCols / 2 - 2);
		posY = Functions.getRandomInt(0, GameScript.nRows - 1);
		
		pUpObserver1 = (GameObject)Instantiate(Resources.Load(Paths.pUpObserver), new Vector3(tilesScripts[posX, posY].transform.position.x, tilesScripts[posX, posY].transform.position.y - charOffsetY, 0), new Quaternion(0, 0, 0, 0));
		
		changeTile(posX, posY, 1);
		tilesScripts[posX, posY].element = "Observer";
		
		Functions.setSpriteAlpha(pUpObserver1, 0.0f);
		//-----------------------------------------------
		posX = Functions.getRandomInt(GameScript.nCols / 2 + 1, GameScript.nCols - 2);
		posY = Functions.getRandomInt(0, GameScript.nRows - 1);
		
		pUpObserver2 = (GameObject)Instantiate(Resources.Load(Paths.pUpObserver), new Vector3(tilesScripts[posX, posY].transform.position.x, tilesScripts[posX, posY].transform.position.y - charOffsetY, 0), new Quaternion(0, 0, 0, 0));
		
		changeTile(posX, posY, 1);
		tilesScripts[posX, posY].element = "Observer";
		
		Functions.setSpriteAlpha(pUpObserver2, 0.0f);
		//-----------------------------------------------
		posX = Functions.getRandomInt(1, GameScript.nCols / 2 - 2);
		posY = Functions.getRandomInt(0, GameScript.nRows - 1);
		
		pUpTornado1 = (GameObject)Instantiate(Resources.Load(Paths.pUpTornado), new Vector3(tilesScripts[posX, posY].transform.position.x, tilesScripts[posX, posY].transform.position.y - charOffsetY, 0), new Quaternion(0, 0, 0, 0));
		
		changeTile(posX, posY, 1);
		tilesScripts[posX, posY].element = "Tornado";
		
		Functions.setSpriteAlpha(pUpTornado1, 0.0f);
		//-----------------------------------------------
		posX = Functions.getRandomInt(GameScript.nCols / 2 + 1, GameScript.nCols - 2);
		posY = Functions.getRandomInt(0, GameScript.nRows - 1);
		
		pUpTornado2 = (GameObject)Instantiate(Resources.Load(Paths.pUpTornado), new Vector3(tilesScripts[posX, posY].transform.position.x, tilesScripts[posX, posY].transform.position.y - charOffsetY, 0), new Quaternion(0, 0, 0, 0));
		
		changeTile(posX, posY, 1);
		tilesScripts[posX, posY].element = "Tornado";
		
		Functions.setSpriteAlpha(pUpTornado2, 0.0f);
		//-----------------------------------------------
		posX = Functions.getRandomInt(1, GameScript.nCols / 2 - 2);
		posY = Functions.getRandomInt(0, GameScript.nRows - 1);
		
		pUpStone1 = (GameObject)Instantiate(Resources.Load(Paths.pUpStone), new Vector3(tilesScripts[posX, posY].transform.position.x, tilesScripts[posX, posY].transform.position.y - charOffsetY, 0), new Quaternion(0, 0, 0, 0));
		
		changeTile(posX, posY, 1);
		tilesScripts[posX, posY].element = "Stone";
		
		Functions.setSpriteAlpha(pUpStone1, 0.0f);
		//-----------------------------------------------
		posX = Functions.getRandomInt(GameScript.nCols / 2 + 1, GameScript.nCols - 2);
		posY = Functions.getRandomInt(0, GameScript.nRows - 1);
		
		pUpStone2 = (GameObject)Instantiate(Resources.Load(Paths.pUpStone), new Vector3(tilesScripts[posX, posY].transform.position.x, tilesScripts[posX, posY].transform.position.y - charOffsetY, 0), new Quaternion(0, 0, 0, 0));
		
		changeTile(posX, posY, 1);
		tilesScripts[posX, posY].element = "Stone";
		
		Functions.setSpriteAlpha(pUpStone2, 0.0f);
    }

    void checkInputExtraTurn() {
        if (playerTurn == 1) {
            if (Input.GetKeyDown(Config.keyA1) && extraElement == scriptA1) {
                extraElement.moveToSelected();
                extraTurn = false;
                extraElement = null;
            }

            if (Input.GetKeyDown(Config.keyB1) && extraElement == scriptB1){
                extraElement.moveToSelected();
                extraTurn = false;
                extraElement = null;
            }

            if (Input.GetKeyDown(Config.keyC1) && extraElement == scriptC1){
                extraElement.moveToSelected();
                extraTurn = false;
                extraElement = null;
            }

            if (Input.GetKeyDown(Config.keyUp1)) {
                scriptSelected.goUp();
            }

            if (Input.GetKeyDown(Config.keyLeft1)) {
                scriptSelected.goLeft();
            }

            if (Input.GetKeyDown(Config.keyDown1)) {
                scriptSelected.goDown();
            }

            if (Input.GetKeyDown(Config.keyRight1)) {
                scriptSelected.goRight();
            }
        } else if (nPlayers == 2) {
            if (Input.GetKeyDown(Config.keyA2) && extraElement == scriptA2){
                extraElement.moveToSelected();
                extraTurn = false;
                extraElement = null;
            }

            if (Input.GetKeyDown(Config.keyB2) && extraElement == scriptB2){
                extraElement.moveToSelected();
                extraTurn = false;
                extraElement = null;
            }

            if (Input.GetKeyDown(Config.keyC2) && extraElement == scriptC2){
                extraElement.moveToSelected();
                extraTurn = false;
                extraElement = null;
            }

            if (Input.GetKeyDown(Config.keyUp2)){
                scriptSelected.goUp();
            }

            if (Input.GetKeyDown(Config.keyLeft2)){
                scriptSelected.goLeft();
            }

            if (Input.GetKeyDown(Config.keyDown2)){
                scriptSelected.goDown();
            }

            if (Input.GetKeyDown(Config.keyRight2)){
                scriptSelected.goRight();
            }
        } else {
            for (int i = 0; i < Functions.getRandomInt(1, 3); i++) {
                scriptSelected.goLeft();
            }

            for (int i = 0; i < Functions.getRandomInt(0, 4); i++) {
                scriptSelected.goUp();
            }

            for (int i = 0; i < Functions.getRandomInt(0, 1); i++) {
                scriptSelected.goLeft();
            }

            for (int i = 0; i < Functions.getRandomInt(0, 2); i++) {
                scriptSelected.goDown();
            }

            extraElement.moveToSelected();
            extraTurn = false;
            extraElement = null;
        }
    }

    void hideTiles() {
        for (int i = 0; i < nRows; i++) {
            for (int j = 0; j < nCols; j++) {
                tilesScripts[j, i].hide();
            }
        }
    }

    void checkInput() {

        if (playerTurn == 1) {
            if (Input.GetKeyDown(Config.keyA1) && !scriptA1.won) {
                if (scriptA1.selected == false) {
                    scriptA1.setSelected(true);
                } else {
                    scriptA1.moveToSelected();
                }
            }

            if (Input.GetKeyDown(Config.keyB1) && !scriptB1.won) {
                if (scriptB1.selected == false) {
                    scriptB1.setSelected(true);
                } else {
                    scriptB1.moveToSelected();
                }
            }

            if (Input.GetKeyDown(Config.keyC1) && !scriptC1.won) {
                if (scriptC1.selected == false){
                    scriptC1.setSelected(true);
                } else {
                    scriptC1.moveToSelected();
                }
            }

            if (Input.GetKeyDown(Config.keyUp1)) {
                scriptSelected.goUp();
            }

            if (Input.GetKeyDown(Config.keyLeft1)) {
                scriptSelected.goLeft();
            }

            if (Input.GetKeyDown(Config.keyDown1)) {
                scriptSelected.goDown();
            }

            if (Input.GetKeyDown(Config.keyRight1)) {
                scriptSelected.goRight();
            }

        } else if (nPlayers == 2){
            if (Input.GetKeyDown(Config.keyA2) && !scriptA2.won) {
                if (scriptA2.selected == false){
                    scriptA2.setSelected(true);
                } else {
                    scriptA2.moveToSelected();
                }
            }

            if (Input.GetKeyDown(Config.keyB2) && !scriptB2.won) {
                if (scriptB2.selected == false){
                    scriptB2.setSelected(true);
                } else {
                    scriptB2.moveToSelected();
                }
            }

            if (Input.GetKeyDown(Config.keyC2) && !scriptC2.won) {
                if (scriptC2.selected == false){
                    scriptC2.setSelected(true);
                } else {
                    scriptC2.moveToSelected();
                }
            }

            if (Input.GetKeyDown(Config.keyUp2)){
                scriptSelected.goUp();
            }

            if (Input.GetKeyDown(Config.keyLeft2)){
                scriptSelected.goLeft();
            }

            if (Input.GetKeyDown(Config.keyDown2)){
                scriptSelected.goDown();
            }

            if (Input.GetKeyDown(Config.keyRight2)){
                scriptSelected.goRight();
            }
        } else {

            if (Functions.getRandomInt(0, 2) == 0 && !scriptA2.won) {
                scriptA2.setSelected(true);
            } else if (Functions.getRandomInt(0, 1) == 1 && !scriptB2.won) {
                scriptB2.setSelected(true);
            } else if (!scriptC2.won) {
                scriptC2.setSelected(true);
            } else {
                scriptA2.setSelected(true);
            }

            for (int i = 0; i < Functions.getRandomInt(1, 3); i++) {
                scriptSelected.goLeft();
            }

            for (int i = 0; i < Functions.getRandomInt(0, 4); i++) {
                scriptSelected.goUp();
            }

            for (int i = 0; i < Functions.getRandomInt(0, 2); i++) {
                scriptSelected.goDown();
            }

            for (int i = 0; i < Functions.getRandomInt(0, 2); i++) {
                scriptSelected.goLeft();
            }


            if (scriptA2.selected) scriptA2.moveToSelected();
            if (scriptB2.selected) scriptB2.moveToSelected();
            if (scriptC2.selected) scriptC2.moveToSelected();
        }
    }

    static public void endTurn() {
        foreach (TilesScript tile in GameScript.tilesScripts) {
            tile.setSelected(false);
        }

        selectedTile = null;

        scriptA1.setSelected(false);
        scriptB1.setSelected(false);
        scriptC1.setSelected(false);

        scriptA2.setSelected(false);
        scriptB2.setSelected(false);
        scriptC2.setSelected(false);

        if (!extraTurn) {
            if (playerTurn == 1){
                if (!scriptA2.won){
                    scriptSelected = scriptA2;
                    scriptA2.setSelected(true);
                    playerTurn = 2;
                } else if (!scriptB2.won) {
                    scriptSelected = scriptB2;
                    scriptB2.setSelected(true);
                    playerTurn = 2;
                } else {
                    scriptSelected = scriptC2;
                    scriptC2.setSelected(true);
                    playerTurn = 2;
                }
				msgPlayer2.display();
            } else {
                if (!scriptA1.won) {
                    scriptSelected = scriptA1;
                    scriptA1.setSelected(true);
                    playerTurn = 1;
                } else if (!scriptB1.won) {
                    scriptSelected = scriptB1;
                    scriptB1.setSelected(true);
                    playerTurn = 1;
                } else {
                    scriptSelected = scriptC1;
                    scriptC1.setSelected(true);
                    playerTurn = 1;
                }
				msgPlayer1.display();
            }
        } else {
            scriptSelected = extraElement;
            scriptSelected.setSelected(true);
        }


        if (scriptA1.won && scriptB1.won && scriptC1.won) {
            gameOver(1);
        }

        if (scriptA2.won && scriptB2.won && scriptC2.won) {
            gameOver(2);
        }
    }

    static void gameOver(int playerWon) {
        if (playerWon == 1) {
            scriptA1.moveX = -4;
            scriptA1.moveY = -1;
            scriptA1.movingWin = true;

            scriptB1.moveX = -4;
            scriptB1.moveY = -1;
            scriptB1.movingWin = true;

            scriptC1.moveX = -4;
            scriptC1.moveY = -1;
            scriptC1.movingWin = true;
        }

        if (playerWon == 2)
        {
            scriptA2.moveX = -4;
            scriptA2.moveY = -1;
            scriptA2.movingWin = true;

            scriptB2.moveX = -4;
            scriptB2.moveY = -1;
            scriptB2.movingWin = true;

            scriptC2.moveX = -4;
            scriptC2.moveY = -1;
            scriptC2.movingWin = true;
        }

    }

    void createCharacters() {
        Vector2 posA1 = new Vector2(tiles[0, 0].transform.position.x, tiles[0, 0].transform.position.y - charOffsetY);
        Vector2 posB1 = new Vector2(tiles[0, (nRows - 1) / 2].transform.position.x, tiles[0, (nRows - 1) / 2].transform.position.y - charOffsetY);
        Vector2 posC1 = new Vector2(tiles[0, nRows - 1].transform.position.x, tiles[0, nRows - 1].transform.position.y - charOffsetY);

        Vector2 posA2 = new Vector2(tiles[nCols - 1, 0].transform.position.x, tiles[nCols - 1, 0].transform.position.y - charOffsetY);
        Vector2 posB2 = new Vector2(tiles[nCols - 1, (nRows - 1) / 2].transform.position.x, tiles[nCols - 1, (nRows - 1) / 2].transform.position.y - charOffsetY);
        Vector2 posC2 = new Vector2(tiles[nCols - 1, nRows - 1].transform.position.x, tiles[nCols - 1, nRows - 1].transform.position.y - charOffsetY);

        charA1 = (GameObject)Instantiate(Resources.Load(Paths.charFire), new Vector3(posA1.x, posA1.y, 0), new Quaternion (0, 0, 0, 0));
        charB1 = (GameObject)Instantiate(Resources.Load(Paths.charWater), new Vector3(posB1.x, posB1.y, 0), new Quaternion(0, 0, 0, 0));
        charC1 = (GameObject)Instantiate(Resources.Load(Paths.charEarth), new Vector3(posC1.x, posC1.y, 0), new Quaternion(0, 0, 0, 0));

        charA2 = (GameObject)Instantiate(Resources.Load(Paths.charFire), new Vector3(posA2.x, posA2.y, 0), new Quaternion(0, 0, 0, 0));
        charB2 = (GameObject)Instantiate(Resources.Load(Paths.charWater), new Vector3(posB2.x, posB2.y, 0), new Quaternion(0, 0, 0, 0));
        charC2 = (GameObject)Instantiate(Resources.Load(Paths.charEarth), new Vector3(posC2.x, posC2.y, 0), new Quaternion(0, 0, 0, 0));


        scriptA1 = charA1.GetComponent<ElementScript>(); scriptA1.posX = 0; scriptA1.posY = 0; scriptA1.player = 1;
        scriptB1 = charB1.GetComponent<ElementScript>(); scriptB1.posX = 0; scriptB1.posY = (nRows - 1) / 2; scriptB1.player = 1;
        scriptC1 = charC1.GetComponent<ElementScript>(); scriptC1.posX = 0; scriptC1.posY = nRows - 1; scriptC1.player = 1;

        scriptA2 = charA2.GetComponent<ElementScript>(); scriptA2.posX = nCols - 1; scriptA2.posY = 0; scriptA2.player = 2;
        scriptB2 = charB2.GetComponent<ElementScript>(); scriptB2.posX = nCols - 1; scriptB2.posY = (nRows - 1) / 2; scriptB2.player = 2;
        scriptC2 = charC2.GetComponent<ElementScript>(); scriptC2.posX = nCols - 1; scriptC2.posY = nRows - 1; scriptC2.player = 2;
    }

	void setMiddleSection(){
		for (int i = 0; i < nRows; i++){
			for (int j = nCols / 2 - 1; j <= nCols / 2; j++){
				changeTile(j, i, 1);
			}
		}
	}

	void setRandomTiles(){
		if (!Config.mirroredTiles){
			for (int i = 0; i < nRows; i++){
				for (int j = 0; j < nCols; j++){
					int rndTile = Functions.getRandomInt(1, tilePaths.Length - 3);
					
					changeTile(j, i, rndTile);
				}
			}
		} else {
			for (int i = 0; i < nRows; i++){
				for (int j = 0; j < nCols / 2 - 1; j++){
					int rndTile = Functions.getRandomInt(1, tilePaths.Length - 3);
					
					changeTile(j, i, rndTile);
					changeTile(nCols - 1 - j, i, rndTile);
				}
			}
		}

	}

    void setAllWaterTiles() {
        for (int i = 0; i < nRows; i++) {
            for (int j = 0; j < nCols; j++) {
                int rndTile = 0;

                changeTile(j, i, rndTile);
            }
        }
    }

	static public void changeTile(int j, int i, int nTile){
		SpriteRenderer renderer = tiles[j, i].GetComponent<SpriteRenderer>();
		
		renderer.sprite = (Sprite)Resources.Load(tilePaths[nTile], typeof(Sprite)) as Sprite;

        if (nTile == 0) tilesScripts[j, i].element = "Hidden";
        if (nTile == 1) tilesScripts[j, i].element = "Neutral";
        if (nTile == 2) tilesScripts[j, i].element = "Fire";
        if (nTile == 3) tilesScripts[j, i].element = "Water";
        if (nTile == 4) tilesScripts[j, i].element = "Earth";
        if (nTile == 5) tilesScripts[j, i].element = "Middle";
        if (nTile == 6) tilesScripts[j, i].element = "Wall";

		map[j, i] = nTile;
	}

    static public void changeTileTransition(int j, int i, int nTile) {
        if (nTile == 0) tilesScripts[j, i].element = "Hidden";
        if (nTile == 1) tilesScripts[j, i].element = "Neutral";
        if (nTile == 2) tilesScripts[j, i].element = "Fire";
        if (nTile == 3) tilesScripts[j, i].element = "Water";
        if (nTile == 4) tilesScripts[j, i].element = "Earth";
        if (nTile == 5) tilesScripts[j, i].element = "Middle";
        if (nTile == 6) tilesScripts[j, i].element = "Wall";

        tilesScripts[j, i].setTransition();

        map[j, i] = nTile;
    }
	
	void createMap(){
		int tilesWholeWidth = nCols * tileWidth;
		int tilesWholeHeight = nRows * tileHeight;

		int startingX = (int)screenWidth / 2 - (int)tilesWholeWidth / 2;
		int startingY = (int)screenHeight / 2 - (int)tilesWholeHeight / 2;

		for (int i = 0; i < nRows; i++){
			for (int j = 0; j < nCols; j++){
				GameObject tile;

				tile = (GameObject)Instantiate (Resources.Load ("Prefabs/TileHidden"), new Vector3(j * tileWidth + startingX + topLeft.x + tileWidth / 2, -i * tileWidth - startingY + topLeft.y - tileWidth / 2, 0), new Quaternion (0, 0, 0, 0));
			
				tiles[j, i] = tile;
				map[j, i] = 0;

                tilesScripts[j, i] = tile.GetComponent<TilesScript>(); tilesScripts[j, i].posX = j; tilesScripts[j, i].posY = i;

                GameObject tile2;

                tile2 = (GameObject)Instantiate(Resources.Load("Prefabs/TileTransition"), new Vector3(j * tileWidth + startingX + topLeft.x + tileWidth / 2, -i * tileWidth - startingY + topLeft.y - tileWidth / 2, 0), new Quaternion(0, 0, 0, 0));
			}
		}
	}

	void setCameraProperties(){
		float UnitsPerPixel = 1f / 100f;
		float PixelsPerUnit = 100f / 1f;

		Camera.main.orthographicSize = Screen.height / 2f;

		screenWidth = (int)Screen.width;
		screenHeight = (int)Screen.height;

		topLeft = new Vector2(-screenWidth / 2, screenHeight / 2);
		botRight = new Vector2(screenWidth / 2, -screenHeight / 2);
	}

	void fillPaths(){
		tilePaths = new string[7];

		tilePaths[0] = Paths.tileHidden;
		tilePaths[1] = Paths.tileNeutral;
		tilePaths[2] = Paths.tileFire;
		tilePaths[3] = Paths.tileWater;
		tilePaths[4] = Paths.tileEarth;
		tilePaths[5] = Paths.tileMiddle;
        tilePaths[6] = Paths.tileWall;
	}
}
